Module security

Module security 

Type wrappers, utility helpers, and constants for CoreWLAN and related security objects.

Structs

Authorization
CipherKeyFlags
Cipher key flags used when setting WEP keys on an interface.
Identity

Enums

ChannelBand
Frequency band of a Wi-Fi channel.
ChannelWidth
Width of a Wi-Fi channel.
ErrorCode
Error codes corresponding to the CWErrorDomain domain.
EventType
CoreWLAN event types that may be monitored by CWWiFiClient.
IbssModeSecurity
IBSS security types used by the deprecated ad-hoc API.
InterfaceMode
Operating mode for a Wi-Fi interface.
KeychainDomain
Keychain domains used by the C utility helpers in CoreWLAN.
PhyMode
IEEE 802.11 physical layer modes reported by CoreWLAN.
Security
Security types advertised by CoreWLAN.

Functions

bssid_did_change_notification
copy_eap_identity_list
Errors
copy_wifi_eap_identity
Errors
country_code_did_change_notification
delete_wifi_eap_username_and_password
Errors
delete_wifi_password
Errors
error_domain
find_wifi_eap_username_and_password
Errors
find_wifi_password
Errors
link_did_change_notification
link_quality_did_change_notification
link_quality_notification_rssi_key
link_quality_notification_transmit_rate_key
merge_networks
mode_did_change_notification
power_did_change_notification
scan_cache_did_update_notification
set_wifi_eap_identity
Errors
set_wifi_eap_username_and_password
Errors
set_wifi_password
Errors
ssid_did_change_notification